import numpy as np
from skcomponents.optics.component import OpticalComponent
from sasktran import Geometry, StokesVector
from skretrieval.core import OpticalGeometry
import copy


class Filter(OpticalComponent):

    def __init__(self, wavelength_nm, transmission):

        self._transmission = transmission
        self._wavelength_nm = wavelength_nm

    def matrix(self, wavelength):
        return np.eye(4) * self.transmission(wavelength)

    def transmission(self, wavelength):
        return np.interp(wavelength, self._wavelength_nm, self._transmission,
                         left=self._transmission[0], right=self._transmission[-1])

    def model_radiance(self, optical_geometry: OpticalGeometry,
                       model_wavel_nm: np.array = None,
                       model_geometry: Geometry = None,
                       radiance: np.array = None,
                       wf: np.array = None):

        new_rad = copy.deepcopy(radiance)
        print(new_rad.shape)
        for widx, (w, t) in enumerate(zip(model_wavel_nm, self.transmission(model_wavel_nm))):
            for ridx, r in enumerate(new_rad[widx]):
                new_rad[widx, ridx] = StokesVector(stokes=np.array(r._stokes) * t, basis=r._basis)
            if wf is not None:
                wf[widx] *= t

        if wf is None:
            return new_rad
        else:
            return new_rad, wf
