import pytest
import numpy as np
from skcomponents.optics import VerticalPolarizer, HorizontalPolarizer


def test_composition_1():

    vp = VerticalPolarizer()
    hp = HorizontalPolarizer()

    p = vp + hp
    assert np.allclose(p.matrix(500.0), np.zeros((4, 4)))


def test_composition_2a():

    vp = VerticalPolarizer()
    hp = HorizontalPolarizer()

    p1 = vp + hp
    p2 = p1 + vp
    assert np.allclose(p2.matrix(500.0), np.zeros((4, 4)))


def test_composition_2b():

    vp = VerticalPolarizer()
    hp = HorizontalPolarizer()

    p1 = vp + hp
    p2 = vp + p1
    assert np.allclose(p2.matrix(500.0), np.zeros((4, 4)))


def test_composition_3():

    vp = VerticalPolarizer()
    hp = HorizontalPolarizer()

    p1 = vp + vp
    p2 = hp + hp
    p3 = p1 + p2

    print('p1:', p1.matrix(500.0))
    print('p2:', p2.matrix(500.0))

    assert np.allclose(p1.matrix(500.0), 0.5 * np.array([[1, -1, 0, 0], [-1, 1, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0]]))
    assert np.allclose(p2.matrix(500.0), 0.5 * np.array([[1, 1, 0, 0], [1, 1, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0]]))
    assert np.allclose(p3.matrix(500.0), np.zeros((4, 4)))